library headers;

import 'package:flutter/material.dart';

class SquareHeader extends StatelessWidget {
  double height;
  Color color;
  SquareHeader({Key key, this.height, this.color}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Container(
      height: height ?? 300,
      color: color ?? Color(0xff615aab),
    );
  }
}

class CircularHeader extends StatelessWidget {
  double height;
  Color color;

  CircularHeader({Key key, this.height, this.color}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Container(
      height: height ?? 300,
      decoration: BoxDecoration(
          color: color ?? Color(0xff615aab),
          borderRadius: BorderRadius.only(
              bottomLeft: Radius.circular(70),
              bottomRight: Radius.circular(70))),
    );
  }
}

class DiagonalHeader extends StatelessWidget {
  int type;
  Color color;
  DiagonalHeader({Key key, this.type, this.color}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      height: double.infinity,
      width: double.infinity,
      //color: Color(0xff615aab),
      child: CustomPaint(painter: _DiagonalHeaderPainter(color, type)),
    );
  }
}

class _DiagonalHeaderPainter extends CustomPainter {
  final Color color;
  final int type;
  _DiagonalHeaderPainter(this.color, this.type);

  @override
  void paint(Canvas canvas, Size size) {
    final paint = new Paint();

    // Properties
    paint.color = this.color ?? Color(0xff615aab);
    paint.style = PaintingStyle.fill; //.fill
    paint.strokeWidth = 2;
    final path = new Path();

    switch (type) {
      case (1):
        path.moveTo(0, size.height * 0.3);
        path.lineTo(size.width, size.height * 0.25);
        path.lineTo(size.width, 0);
        path.lineTo(0, 0);
        path.lineTo(0, size.height * 0.3);
        break;

      case (2):
        path.lineTo(size.width, size.height);
        path.lineTo(size.width, 0);
        path.lineTo(0, 0);
        break;

      case (3):
        path.lineTo(0, size.height * 0.3);
        path.lineTo(size.width * 0.5, size.height * 0.25);
        path.lineTo(size.width, size.height * 0.3);
        path.lineTo(size.width, 0);
        path.lineTo(0, 0);
        break;

      case (4):
        path.lineTo(0, size.height * 0.3);
        path.lineTo(size.width * 0.5, size.height * 0.35);
        path.lineTo(size.width, size.height * 0.3);
        path.lineTo(size.width, 0);
        path.lineTo(0, 0);
        break;

      default:
        path.lineTo(0, size.height * 0.3);
        path.lineTo(size.width * 0.5, size.height * 0.35);
        path.lineTo(size.width, size.height * 0.3);
        path.lineTo(size.width, 0);
        path.lineTo(0, 0);
    }
    canvas.drawPath(path, paint);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return true;
  }
}

class CurvedHeader extends StatelessWidget {
  Color color;

  CurvedHeader({Key key, this.color}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      height: double.infinity,
      width: double.infinity,
      //color: Color(0xff615aab),
      child: CustomPaint(painter: _CurvedHeaderPainter(color)),
    );
  }
}

class _CurvedHeaderPainter extends CustomPainter {
  final Color color;
  _CurvedHeaderPainter(this.color);
  @override
  void paint(Canvas canvas, Size size) {
    final paint = new Paint();

    // Properties
    paint.color = color ?? Color(0xff615aab);
    paint.style = PaintingStyle.fill; //.fill
    paint.strokeWidth = 20;

    final path = new Path();

    path.lineTo(0, size.height * 0.25);
    path.quadraticBezierTo(
        size.width / 2, size.height * 0.5, size.width, size.height * 0.25);

    path.lineTo(size.width, 0);

    canvas.drawPath(path, paint);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return true;
  }
}

class WavesHeader extends StatelessWidget {
  Color color;
  WavesHeader({Key key, this.color}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      height: double.infinity,
      width: double.infinity,
      //color: Color(0xff615aab),
      child: CustomPaint(painter: _WavesHeaderPainter(color)),
    );
  }
}

class _WavesHeaderPainter extends CustomPainter {
  final Color color;
  _WavesHeaderPainter(this.color);
  @override
  void paint(Canvas canvas, Size size) {
    final paint = new Paint();

    // Properties
    paint.color = color ?? Color(0xff615aab);
    paint.style = PaintingStyle.fill; //.fill
    paint.strokeWidth = 20;

    final path = new Path();

    path.lineTo(0, size.height * 0.25);
    path.quadraticBezierTo(size.width * 0.25, size.height * 0.32,
        size.width * 0.5, size.height * 0.25);

    path.quadraticBezierTo(
        size.width * 0.75, size.height * .18, size.width, size.height * 0.25);

    path.lineTo(size.width, 0);

    canvas.drawPath(path, paint);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return true;
  }
}
